@@ -5,17 +5,14 @@
 
 import logging
 import sys
-import warnings
 
 import asyncclick as click
 
-from . import __version__
-from .ble import repl_loop, scanner, send_text
-from .gui import App
+from . import __version__, ble
 
 
 def ble_receive_callback(data: bytes):
-    """Print data received from BLE."""
+    """Print data received from Bluetooth LE."""
     click.echo(data)
 
 
@@ -47,26 +44,26 @@ def cli(ctx, adapter):
     help="sleep between messages sent with --loop",
 )
 @click.option(
-    "--ble-connection-timeout",
+    "--timeout",
     default=10,
     show_default="10 secs",
     type=float,
-    help="BLE connection timeout",
+    help="Bluetooth LE connection timeout",
 )
 @click.argument("words", type=str, nargs=-1)
 @click.pass_context
-async def send(ctx, words, device, loop, sleep_time, ble_connection_timeout):
+async def send(ctx, words, device, loop, sleep_time, timeout):
     """Send one or more words over BLE to a specific device."""
     msg = " ".join(words)
     logging.info(f"Connecting to {device}...")
     try:
-        await send_text(
+        await ble.send_text(
             ctx.obj["ADAPTER"],
             msg,
             device,
             loop,
             sleep_time,
-            ble_connection_timeout,
+            timeout,
             ble_receive_callback,
         )
     except AssertionError as e:
@@ -77,18 +74,12 @@ async def send(ctx, words, device, loop, sleep_time, ble_connection_timeout):
 @click.option(
     "--scan-time", default=5, show_default="5 secs", type=float, help="scan duration"
 )
-@click.option(
-    "--service-uuid",
-    default=None,
-    show_default="None",
-    type=str,
-    help="service UUID used to filter",
-)
 @click.pass_context
-async def scan(ctx, scan_time, service_uuid):
+async def scan(ctx, scan_time):
     """Scan to find BLE devices."""
-    devices = await scanner.scan(ctx.obj["ADAPTER"], scan_time, service_uuid)
-    scanner.print_list(devices)
+    devices = await ble.scan(ctx.obj["ADAPTER"], scan_time)
+    for device in devices:
+        print(f"{device.address} (rssi:{device.rssi}) {device.name}")
 
 
 @cli.command()
@@ -100,40 +91,19 @@ async def scan(ctx, scan_time, service_uuid):
     help="ble device address",
 )
 @click.option(
-    "--scan-time", default=5, show_default="5 secs", type=float, help="scan duration"
-)
-@click.pass_context
-async def deep_scan(ctx, device, scan_time):
-    """Scan to find services of a specific device."""
-    devices = await scanner.scan(ctx.obj["ADAPTER"], scan_time, None)
-    with warnings.catch_warnings():
-        warnings.simplefilter(action="ignore", category=FutureWarning)
-        services = await scanner.deep_scan(device, devices)
-    scanner.print_details(services)
-
-
-@cli.command()
-@click.option(
-    "--device",
-    required=True,
-    type=str,
-    envvar="FREAKBLE_DEVICE",
-    help="ble device address",
-)
-@click.option(
-    "--ble-connection-timeout",
+    "--timeout",
     default=10,
     show_default="10 secs",
     type=float,
-    help="BLE connection timeout",
+    help="Bluetooth LE connection timeout",
 )
 @click.pass_context
-async def repl(ctx, device, ble_connection_timeout):
+async def repl(ctx, device, timeout):
     """Start a REPL with the device."""
     click.echo(f"freakble {__version__} on {sys.platform}")
     click.echo(f"Connecting to {device}...")
     try:
-        await repl_loop(ctx.obj["ADAPTER"], device, ble_connection_timeout)
+        await ble.repl_loop(ctx.obj["ADAPTER"], device, timeout)
     except AssertionError as e:
         click.echo(click.style(e, fg="red"))
 
@@ -151,15 +121,19 @@ async def repl(ctx, device, ble_connection_timeout):
     default=10,
     show_default="10 secs",
     type=float,
-    help="BLE connection timeout",
+    help="Bluetooth LE connection timeout",
 )
 @click.pass_context
 async def gui(ctx, device, ble_connection_timeout):
     """Start freakble GUI."""
 
-    app = App()
-    app.config(ctx.obj["ADAPTER"], device, ble_connection_timeout)
-    await app.run()
+    # Imported here so that the others commands will works if tkinter is not
+    # installed. It's OK to blow up to let user know for now.
+    from .gui import App
+
+    with App() as app:
+        app.config(ctx.obj["ADAPTER"], device, ble_connection_timeout)
+        await app.run()
 
 
 @cli.command()
